# syndb-api-client
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.6.9
- Package version: 0.6.14
- Generator version: 7.7.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import syndb_api_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import syndb_api_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import syndb_api_client
from syndb_api_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = syndb_api_client.Configuration(
    host = "http://localhost"
)



# Enter a context with an instance of the API client
with syndb_api_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = syndb_api_client.AuthApi(api_client)
    username = 'username_example' # str | 
    password = 'password_example' # str | 
    grant_type = 'grant_type_example' # str |  (optional)
    scope = '' # str |  (optional) (default to '')
    client_id = 'client_id_example' # str |  (optional)
    client_secret = 'client_secret_example' # str |  (optional)

    try:
        # Auth:Db-Native.Login
        api_response = api_instance.auth_db_native_login_user_auth_native_login_post(username, password, grant_type=grant_type, scope=scope, client_id=client_id, client_secret=client_secret)
        print("The response of AuthApi->auth_db_native_login_user_auth_native_login_post:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AuthApi->auth_db_native_login_user_auth_native_login_post: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AuthApi* | [**auth_db_native_login_user_auth_native_login_post**](docs/AuthApi.md#auth_db_native_login_user_auth_native_login_post) | **POST** /user/auth/native/login | Auth:Db-Native.Login
*AuthApi* | [**auth_db_native_logout_user_auth_native_logout_post**](docs/AuthApi.md#auth_db_native_logout_user_auth_native_logout_post) | **POST** /user/auth/native/logout | Auth:Db-Native.Logout
*BenchmarkApi* | [**neurodata_upload_benchmark_data_neurodata_benchmark_neurodata_upload_benchmark_results_get**](docs/BenchmarkApi.md#neurodata_upload_benchmark_data_neurodata_benchmark_neurodata_upload_benchmark_results_get) | **GET** /neurodata/benchmark/neurodata_upload_benchmark_results | Neurodata Upload Benchmark Data
*BenchmarkApi* | [**tag_search_download_benchmark_results_neurodata_benchmark_neurodata_download_benchmark_results_get**](docs/BenchmarkApi.md#tag_search_download_benchmark_results_neurodata_benchmark_neurodata_download_benchmark_results_get) | **GET** /neurodata/benchmark/neurodata_download/benchmark_results | Tag Search Download Benchmark Results
*BenchmarkApi* | [**tag_search_upload_benchmark_result_neurodata_benchmark_neurodata_download_upload_benchmark_result_post**](docs/BenchmarkApi.md#tag_search_upload_benchmark_result_neurodata_benchmark_neurodata_download_upload_benchmark_result_post) | **POST** /neurodata/benchmark/neurodata_download/upload_benchmark_result | Tag Search Upload Benchmark Result
*CilogonApi* | [**academic_authorize_user_academic_authorize_get**](docs/CilogonApi.md#academic_authorize_user_academic_authorize_get) | **GET** /user/academic/authorize | Academic:Authorize
*CilogonApi* | [**academic_callback_user_academic_callback_get**](docs/CilogonApi.md#academic_callback_user_academic_callback_get) | **GET** /user/academic/callback | Academic:Callback
*DatasetApi* | [**all_datasets_neurodata_metadata_dataset_get_all_get**](docs/DatasetApi.md#all_datasets_neurodata_metadata_dataset_get_all_get) | **GET** /neurodata/metadata/dataset/get/all | All Datasets
*DatasetApi* | [**dataset_info_neurodata_metadata_dataset_dataset_id_info_get**](docs/DatasetApi.md#dataset_info_neurodata_metadata_dataset_dataset_id_info_get) | **GET** /neurodata/metadata/dataset/{dataset_id}/info | Dataset Info
*DatasetApi* | [**dataset_tag_search_neurodata_metadata_dataset_search_post**](docs/DatasetApi.md#dataset_tag_search_neurodata_metadata_dataset_search_post) | **POST** /neurodata/metadata/dataset/search | Dataset Tag Search
*DatasetApi* | [**incomplete_datasets_neurodata_metadata_dataset_get_incomplete_get**](docs/DatasetApi.md#incomplete_datasets_neurodata_metadata_dataset_get_incomplete_get) | **GET** /neurodata/metadata/dataset/get/incomplete | Incomplete Datasets
*DatasetApi* | [**modifiable_datasets_neurodata_metadata_dataset_get_modifiable_get**](docs/DatasetApi.md#modifiable_datasets_neurodata_metadata_dataset_get_modifiable_get) | **GET** /neurodata/metadata/dataset/get/modifiable | Modifiable Datasets
*DatasetApi* | [**new_dataset_collection_neurodata_metadata_dataset_collection_new_simple_post**](docs/DatasetApi.md#new_dataset_collection_neurodata_metadata_dataset_collection_new_simple_post) | **POST** /neurodata/metadata/dataset/collection/new/simple | New Dataset Collection
*DatasetApi* | [**new_multi_region_dataset_collection_neurodata_metadata_dataset_collection_new_multi_brain_region_post**](docs/DatasetApi.md#new_multi_region_dataset_collection_neurodata_metadata_dataset_collection_new_multi_brain_region_post) | **POST** /neurodata/metadata/dataset/collection/new/multi-brain-region | New Multi Region Dataset Collection
*DatasetApi* | [**register_new_dataset_neurodata_metadata_dataset_new_post**](docs/DatasetApi.md#register_new_dataset_neurodata_metadata_dataset_new_post) | **POST** /neurodata/metadata/dataset/new | Register New Dataset
*DefaultApi* | [**redirect_get**](docs/DefaultApi.md#redirect_get) | **GET** / | Redirect
*ExternalApi* | [**download_data_neurodata_io_download_url_get**](docs/ExternalApi.md#download_data_neurodata_io_download_url_get) | **GET** /neurodata/io/download_url | Download Data
*ExternalApi* | [**upload_dataset_mesh_neurodata_io_dataset_id_upload_url_mesh_get**](docs/ExternalApi.md#upload_dataset_mesh_neurodata_io_dataset_id_upload_url_mesh_get) | **GET** /neurodata/io/{dataset_id}/upload_url/mesh | Upload Dataset Mesh
*ExternalApi* | [**upload_dataset_swb_neurodata_io_dataset_id_upload_url_swb_get**](docs/ExternalApi.md#upload_dataset_swb_neurodata_io_dataset_id_upload_url_swb_get) | **GET** /neurodata/io/{dataset_id}/upload_url/swb | Upload Dataset Swb
*GithubApi* | [**oauth_github_db_github_authorize_user_auth_oauth_github_authorize_get**](docs/GithubApi.md#oauth_github_db_github_authorize_user_auth_oauth_github_authorize_get) | **GET** /user/auth/oauth/github/authorize | Oauth:Github.Db-Github.Authorize
*GithubApi* | [**oauth_github_db_github_callback_user_auth_oauth_github_callback_get**](docs/GithubApi.md#oauth_github_db_github_callback_user_auth_oauth_github_callback_get) | **GET** /user/auth/oauth/github/callback | Oauth:Github.Db-Github.Callback
*GoogleApi* | [**oauth_google_db_google_authorize_user_auth_oauth_google_authorize_get**](docs/GoogleApi.md#oauth_google_db_google_authorize_user_auth_oauth_google_authorize_get) | **GET** /user/auth/oauth/google/authorize | Oauth:Google.Db-Google.Authorize
*GoogleApi* | [**oauth_google_db_google_callback_user_auth_oauth_google_callback_get**](docs/GoogleApi.md#oauth_google_db_google_callback_user_auth_oauth_google_callback_get) | **GET** /user/auth/oauth/google/callback | Oauth:Google.Db-Google.Callback
*IoApi* | [**delete_dataset_neurodata_io_dataset_id_delete_dataset_delete**](docs/IoApi.md#delete_dataset_neurodata_io_dataset_id_delete_dataset_delete) | **DELETE** /neurodata/io/{dataset_id}/delete_dataset | Delete Dataset
*IoApi* | [**download_data_neurodata_io_download_url_get**](docs/IoApi.md#download_data_neurodata_io_download_url_get) | **GET** /neurodata/io/download_url | Download Data
*IoApi* | [**download_dataset_files_neurodata_io_download_dataset_post**](docs/IoApi.md#download_dataset_files_neurodata_io_download_dataset_post) | **POST** /neurodata/io/download_dataset | Download Dataset Files
*IoApi* | [**upload_dataset_files_neurodata_io_dataset_id_upload_patch**](docs/IoApi.md#upload_dataset_files_neurodata_io_dataset_id_upload_patch) | **PATCH** /neurodata/io/{dataset_id}/upload | Upload Dataset Files
*IoApi* | [**upload_dataset_mesh_neurodata_io_dataset_id_upload_url_mesh_get**](docs/IoApi.md#upload_dataset_mesh_neurodata_io_dataset_id_upload_url_mesh_get) | **GET** /neurodata/io/{dataset_id}/upload_url/mesh | Upload Dataset Mesh
*IoApi* | [**upload_dataset_swb_neurodata_io_dataset_id_upload_url_swb_get**](docs/IoApi.md#upload_dataset_swb_neurodata_io_dataset_id_upload_url_swb_get) | **GET** /neurodata/io/{dataset_id}/upload_url/swb | Upload Dataset Swb
*MetadataApi* | [**all_datasets_neurodata_metadata_dataset_get_all_get**](docs/MetadataApi.md#all_datasets_neurodata_metadata_dataset_get_all_get) | **GET** /neurodata/metadata/dataset/get/all | All Datasets
*MetadataApi* | [**create_animal_neurodata_metadata_tag_animal_create_post**](docs/MetadataApi.md#create_animal_neurodata_metadata_tag_animal_create_post) | **POST** /neurodata/metadata/tag/animal/create | Create Animal
*MetadataApi* | [**create_brain_region_neurodata_metadata_tag_brain_region_create_post**](docs/MetadataApi.md#create_brain_region_neurodata_metadata_tag_brain_region_create_post) | **POST** /neurodata/metadata/tag/brain_region/create | Create Brain Region
*MetadataApi* | [**create_microscopy_neurodata_metadata_tag_microscopy_create_post**](docs/MetadataApi.md#create_microscopy_neurodata_metadata_tag_microscopy_create_post) | **POST** /neurodata/metadata/tag/microscopy/create | Create Microscopy
*MetadataApi* | [**create_mutation_neurodata_metadata_tag_mutation_create_post**](docs/MetadataApi.md#create_mutation_neurodata_metadata_tag_mutation_create_post) | **POST** /neurodata/metadata/tag/mutation/create | Create Mutation
*MetadataApi* | [**create_publication_neurodata_metadata_tag_publication_create_post**](docs/MetadataApi.md#create_publication_neurodata_metadata_tag_publication_create_post) | **POST** /neurodata/metadata/tag/publication/create | Create Publication
*MetadataApi* | [**dataset_info_neurodata_metadata_dataset_dataset_id_info_get**](docs/MetadataApi.md#dataset_info_neurodata_metadata_dataset_dataset_id_info_get) | **GET** /neurodata/metadata/dataset/{dataset_id}/info | Dataset Info
*MetadataApi* | [**dataset_tag_search_neurodata_metadata_dataset_search_post**](docs/MetadataApi.md#dataset_tag_search_neurodata_metadata_dataset_search_post) | **POST** /neurodata/metadata/dataset/search | Dataset Tag Search
*MetadataApi* | [**incomplete_datasets_neurodata_metadata_dataset_get_incomplete_get**](docs/MetadataApi.md#incomplete_datasets_neurodata_metadata_dataset_get_incomplete_get) | **GET** /neurodata/metadata/dataset/get/incomplete | Incomplete Datasets
*MetadataApi* | [**modifiable_datasets_neurodata_metadata_dataset_get_modifiable_get**](docs/MetadataApi.md#modifiable_datasets_neurodata_metadata_dataset_get_modifiable_get) | **GET** /neurodata/metadata/dataset/get/modifiable | Modifiable Datasets
*MetadataApi* | [**new_dataset_collection_neurodata_metadata_dataset_collection_new_simple_post**](docs/MetadataApi.md#new_dataset_collection_neurodata_metadata_dataset_collection_new_simple_post) | **POST** /neurodata/metadata/dataset/collection/new/simple | New Dataset Collection
*MetadataApi* | [**new_multi_region_dataset_collection_neurodata_metadata_dataset_collection_new_multi_brain_region_post**](docs/MetadataApi.md#new_multi_region_dataset_collection_neurodata_metadata_dataset_collection_new_multi_brain_region_post) | **POST** /neurodata/metadata/dataset/collection/new/multi-brain-region | New Multi Region Dataset Collection
*MetadataApi* | [**register_new_dataset_neurodata_metadata_dataset_new_post**](docs/MetadataApi.md#register_new_dataset_neurodata_metadata_dataset_new_post) | **POST** /neurodata/metadata/dataset/new | Register New Dataset
*MetadataApi* | [**universal_metadata_neurodata_metadata_get_universal_get**](docs/MetadataApi.md#universal_metadata_neurodata_metadata_get_universal_get) | **GET** /neurodata/metadata/get/universal | Universal Metadata
*MetadataApi* | [**user_metadata_neurodata_metadata_get_user_get**](docs/MetadataApi.md#user_metadata_neurodata_metadata_get_user_get) | **GET** /neurodata/metadata/get/user | User Metadata
*NeurodataApi* | [**all_datasets_neurodata_metadata_dataset_get_all_get**](docs/NeurodataApi.md#all_datasets_neurodata_metadata_dataset_get_all_get) | **GET** /neurodata/metadata/dataset/get/all | All Datasets
*NeurodataApi* | [**create_animal_neurodata_metadata_tag_animal_create_post**](docs/NeurodataApi.md#create_animal_neurodata_metadata_tag_animal_create_post) | **POST** /neurodata/metadata/tag/animal/create | Create Animal
*NeurodataApi* | [**create_brain_region_neurodata_metadata_tag_brain_region_create_post**](docs/NeurodataApi.md#create_brain_region_neurodata_metadata_tag_brain_region_create_post) | **POST** /neurodata/metadata/tag/brain_region/create | Create Brain Region
*NeurodataApi* | [**create_microscopy_neurodata_metadata_tag_microscopy_create_post**](docs/NeurodataApi.md#create_microscopy_neurodata_metadata_tag_microscopy_create_post) | **POST** /neurodata/metadata/tag/microscopy/create | Create Microscopy
*NeurodataApi* | [**create_mutation_neurodata_metadata_tag_mutation_create_post**](docs/NeurodataApi.md#create_mutation_neurodata_metadata_tag_mutation_create_post) | **POST** /neurodata/metadata/tag/mutation/create | Create Mutation
*NeurodataApi* | [**create_publication_neurodata_metadata_tag_publication_create_post**](docs/NeurodataApi.md#create_publication_neurodata_metadata_tag_publication_create_post) | **POST** /neurodata/metadata/tag/publication/create | Create Publication
*NeurodataApi* | [**dataset_info_neurodata_metadata_dataset_dataset_id_info_get**](docs/NeurodataApi.md#dataset_info_neurodata_metadata_dataset_dataset_id_info_get) | **GET** /neurodata/metadata/dataset/{dataset_id}/info | Dataset Info
*NeurodataApi* | [**dataset_tag_search_neurodata_metadata_dataset_search_post**](docs/NeurodataApi.md#dataset_tag_search_neurodata_metadata_dataset_search_post) | **POST** /neurodata/metadata/dataset/search | Dataset Tag Search
*NeurodataApi* | [**delete_dataset_neurodata_io_dataset_id_delete_dataset_delete**](docs/NeurodataApi.md#delete_dataset_neurodata_io_dataset_id_delete_dataset_delete) | **DELETE** /neurodata/io/{dataset_id}/delete_dataset | Delete Dataset
*NeurodataApi* | [**download_data_neurodata_io_download_url_get**](docs/NeurodataApi.md#download_data_neurodata_io_download_url_get) | **GET** /neurodata/io/download_url | Download Data
*NeurodataApi* | [**download_dataset_files_neurodata_io_download_dataset_post**](docs/NeurodataApi.md#download_dataset_files_neurodata_io_download_dataset_post) | **POST** /neurodata/io/download_dataset | Download Dataset Files
*NeurodataApi* | [**incomplete_datasets_neurodata_metadata_dataset_get_incomplete_get**](docs/NeurodataApi.md#incomplete_datasets_neurodata_metadata_dataset_get_incomplete_get) | **GET** /neurodata/metadata/dataset/get/incomplete | Incomplete Datasets
*NeurodataApi* | [**modifiable_datasets_neurodata_metadata_dataset_get_modifiable_get**](docs/NeurodataApi.md#modifiable_datasets_neurodata_metadata_dataset_get_modifiable_get) | **GET** /neurodata/metadata/dataset/get/modifiable | Modifiable Datasets
*NeurodataApi* | [**neurodata_upload_benchmark_data_neurodata_benchmark_neurodata_upload_benchmark_results_get**](docs/NeurodataApi.md#neurodata_upload_benchmark_data_neurodata_benchmark_neurodata_upload_benchmark_results_get) | **GET** /neurodata/benchmark/neurodata_upload_benchmark_results | Neurodata Upload Benchmark Data
*NeurodataApi* | [**new_dataset_collection_neurodata_metadata_dataset_collection_new_simple_post**](docs/NeurodataApi.md#new_dataset_collection_neurodata_metadata_dataset_collection_new_simple_post) | **POST** /neurodata/metadata/dataset/collection/new/simple | New Dataset Collection
*NeurodataApi* | [**new_multi_region_dataset_collection_neurodata_metadata_dataset_collection_new_multi_brain_region_post**](docs/NeurodataApi.md#new_multi_region_dataset_collection_neurodata_metadata_dataset_collection_new_multi_brain_region_post) | **POST** /neurodata/metadata/dataset/collection/new/multi-brain-region | New Multi Region Dataset Collection
*NeurodataApi* | [**register_new_dataset_neurodata_metadata_dataset_new_post**](docs/NeurodataApi.md#register_new_dataset_neurodata_metadata_dataset_new_post) | **POST** /neurodata/metadata/dataset/new | Register New Dataset
*NeurodataApi* | [**tag_search_download_benchmark_results_neurodata_benchmark_neurodata_download_benchmark_results_get**](docs/NeurodataApi.md#tag_search_download_benchmark_results_neurodata_benchmark_neurodata_download_benchmark_results_get) | **GET** /neurodata/benchmark/neurodata_download/benchmark_results | Tag Search Download Benchmark Results
*NeurodataApi* | [**tag_search_upload_benchmark_result_neurodata_benchmark_neurodata_download_upload_benchmark_result_post**](docs/NeurodataApi.md#tag_search_upload_benchmark_result_neurodata_benchmark_neurodata_download_upload_benchmark_result_post) | **POST** /neurodata/benchmark/neurodata_download/upload_benchmark_result | Tag Search Upload Benchmark Result
*NeurodataApi* | [**universal_metadata_neurodata_metadata_get_universal_get**](docs/NeurodataApi.md#universal_metadata_neurodata_metadata_get_universal_get) | **GET** /neurodata/metadata/get/universal | Universal Metadata
*NeurodataApi* | [**upload_dataset_files_neurodata_io_dataset_id_upload_patch**](docs/NeurodataApi.md#upload_dataset_files_neurodata_io_dataset_id_upload_patch) | **PATCH** /neurodata/io/{dataset_id}/upload | Upload Dataset Files
*NeurodataApi* | [**upload_dataset_mesh_neurodata_io_dataset_id_upload_url_mesh_get**](docs/NeurodataApi.md#upload_dataset_mesh_neurodata_io_dataset_id_upload_url_mesh_get) | **GET** /neurodata/io/{dataset_id}/upload_url/mesh | Upload Dataset Mesh
*NeurodataApi* | [**upload_dataset_swb_neurodata_io_dataset_id_upload_url_swb_get**](docs/NeurodataApi.md#upload_dataset_swb_neurodata_io_dataset_id_upload_url_swb_get) | **GET** /neurodata/io/{dataset_id}/upload_url/swb | Upload Dataset Swb
*NeurodataApi* | [**user_metadata_neurodata_metadata_get_user_get**](docs/NeurodataApi.md#user_metadata_neurodata_metadata_get_user_get) | **GET** /neurodata/metadata/get/user | User Metadata
*OauthApi* | [**academic_authorize_user_academic_authorize_get**](docs/OauthApi.md#academic_authorize_user_academic_authorize_get) | **GET** /user/academic/authorize | Academic:Authorize
*OauthApi* | [**academic_callback_user_academic_callback_get**](docs/OauthApi.md#academic_callback_user_academic_callback_get) | **GET** /user/academic/callback | Academic:Callback
*OauthApi* | [**oauth_associate_orcid_authorize_user_auth_oauth_orcid_authorize_get**](docs/OauthApi.md#oauth_associate_orcid_authorize_user_auth_oauth_orcid_authorize_get) | **GET** /user/auth/oauth/orcid/authorize | Oauth-Associate:Orcid.Authorize
*OauthApi* | [**oauth_associate_orcid_callback_user_auth_oauth_orcid_callback_get**](docs/OauthApi.md#oauth_associate_orcid_callback_user_auth_oauth_orcid_callback_get) | **GET** /user/auth/oauth/orcid/callback | Oauth-Associate:Orcid.Callback
*OauthApi* | [**oauth_github_db_github_authorize_user_auth_oauth_github_authorize_get**](docs/OauthApi.md#oauth_github_db_github_authorize_user_auth_oauth_github_authorize_get) | **GET** /user/auth/oauth/github/authorize | Oauth:Github.Db-Github.Authorize
*OauthApi* | [**oauth_github_db_github_callback_user_auth_oauth_github_callback_get**](docs/OauthApi.md#oauth_github_db_github_callback_user_auth_oauth_github_callback_get) | **GET** /user/auth/oauth/github/callback | Oauth:Github.Db-Github.Callback
*OauthApi* | [**oauth_google_db_google_authorize_user_auth_oauth_google_authorize_get**](docs/OauthApi.md#oauth_google_db_google_authorize_user_auth_oauth_google_authorize_get) | **GET** /user/auth/oauth/google/authorize | Oauth:Google.Db-Google.Authorize
*OauthApi* | [**oauth_google_db_google_callback_user_auth_oauth_google_callback_get**](docs/OauthApi.md#oauth_google_db_google_callback_user_auth_oauth_google_callback_get) | **GET** /user/auth/oauth/google/callback | Oauth:Google.Db-Google.Callback
*OrcidApi* | [**oauth_associate_orcid_authorize_user_auth_oauth_orcid_authorize_get**](docs/OrcidApi.md#oauth_associate_orcid_authorize_user_auth_oauth_orcid_authorize_get) | **GET** /user/auth/oauth/orcid/authorize | Oauth-Associate:Orcid.Authorize
*OrcidApi* | [**oauth_associate_orcid_callback_user_auth_oauth_orcid_callback_get**](docs/OrcidApi.md#oauth_associate_orcid_callback_user_auth_oauth_orcid_callback_get) | **GET** /user/auth/oauth/orcid/callback | Oauth-Associate:Orcid.Callback
*TagApi* | [**create_animal_neurodata_metadata_tag_animal_create_post**](docs/TagApi.md#create_animal_neurodata_metadata_tag_animal_create_post) | **POST** /neurodata/metadata/tag/animal/create | Create Animal
*TagApi* | [**create_brain_region_neurodata_metadata_tag_brain_region_create_post**](docs/TagApi.md#create_brain_region_neurodata_metadata_tag_brain_region_create_post) | **POST** /neurodata/metadata/tag/brain_region/create | Create Brain Region
*TagApi* | [**create_microscopy_neurodata_metadata_tag_microscopy_create_post**](docs/TagApi.md#create_microscopy_neurodata_metadata_tag_microscopy_create_post) | **POST** /neurodata/metadata/tag/microscopy/create | Create Microscopy
*TagApi* | [**create_mutation_neurodata_metadata_tag_mutation_create_post**](docs/TagApi.md#create_mutation_neurodata_metadata_tag_mutation_create_post) | **POST** /neurodata/metadata/tag/mutation/create | Create Mutation
*TagApi* | [**create_publication_neurodata_metadata_tag_publication_create_post**](docs/TagApi.md#create_publication_neurodata_metadata_tag_publication_create_post) | **POST** /neurodata/metadata/tag/publication/create | Create Publication
*UserApi* | [**academic_authorize_user_academic_authorize_get**](docs/UserApi.md#academic_authorize_user_academic_authorize_get) | **GET** /user/academic/authorize | Academic:Authorize
*UserApi* | [**academic_callback_user_academic_callback_get**](docs/UserApi.md#academic_callback_user_academic_callback_get) | **GET** /user/academic/callback | Academic:Callback
*UserApi* | [**auth_db_native_login_user_auth_native_login_post**](docs/UserApi.md#auth_db_native_login_user_auth_native_login_post) | **POST** /user/auth/native/login | Auth:Db-Native.Login
*UserApi* | [**auth_db_native_login_user_auth_native_login_post_0**](docs/UserApi.md#auth_db_native_login_user_auth_native_login_post_0) | **POST** /user/auth/native/login | Auth:Db-Native.Login
*UserApi* | [**auth_db_native_logout_user_auth_native_logout_post**](docs/UserApi.md#auth_db_native_logout_user_auth_native_logout_post) | **POST** /user/auth/native/logout | Auth:Db-Native.Logout
*UserApi* | [**auth_db_native_logout_user_auth_native_logout_post_0**](docs/UserApi.md#auth_db_native_logout_user_auth_native_logout_post_0) | **POST** /user/auth/native/logout | Auth:Db-Native.Logout
*UserApi* | [**current_user_profile_user_profile_current_get**](docs/UserApi.md#current_user_profile_user_profile_current_get) | **GET** /user/profile/current | Current User Profile
*UserApi* | [**oauth_associate_orcid_authorize_user_auth_oauth_orcid_authorize_get**](docs/UserApi.md#oauth_associate_orcid_authorize_user_auth_oauth_orcid_authorize_get) | **GET** /user/auth/oauth/orcid/authorize | Oauth-Associate:Orcid.Authorize
*UserApi* | [**oauth_associate_orcid_callback_user_auth_oauth_orcid_callback_get**](docs/UserApi.md#oauth_associate_orcid_callback_user_auth_oauth_orcid_callback_get) | **GET** /user/auth/oauth/orcid/callback | Oauth-Associate:Orcid.Callback
*UserApi* | [**oauth_github_db_github_authorize_user_auth_oauth_github_authorize_get**](docs/UserApi.md#oauth_github_db_github_authorize_user_auth_oauth_github_authorize_get) | **GET** /user/auth/oauth/github/authorize | Oauth:Github.Db-Github.Authorize
*UserApi* | [**oauth_github_db_github_callback_user_auth_oauth_github_callback_get**](docs/UserApi.md#oauth_github_db_github_callback_user_auth_oauth_github_callback_get) | **GET** /user/auth/oauth/github/callback | Oauth:Github.Db-Github.Callback
*UserApi* | [**oauth_google_db_google_authorize_user_auth_oauth_google_authorize_get**](docs/UserApi.md#oauth_google_db_google_authorize_user_auth_oauth_google_authorize_get) | **GET** /user/auth/oauth/google/authorize | Oauth:Google.Db-Google.Authorize
*UserApi* | [**oauth_google_db_google_callback_user_auth_oauth_google_callback_get**](docs/UserApi.md#oauth_google_db_google_callback_user_auth_oauth_google_callback_get) | **GET** /user/auth/oauth/google/callback | Oauth:Google.Db-Google.Callback
*UserApi* | [**profile_from_scientist_tag_user_profile_scientist_tag_scientist_tag_get**](docs/UserApi.md#profile_from_scientist_tag_user_profile_scientist_tag_scientist_tag_get) | **GET** /user/profile/scientist_tag/{scientist_tag} | Profile From Scientist Tag
*UserApi* | [**profile_from_user_id_user_profile_id_user_id_get**](docs/UserApi.md#profile_from_user_id_user_profile_id_user_id_get) | **GET** /user/profile/id/{user_id} | Profile From User Id
*UserApi* | [**register_register_user_auth_register_post**](docs/UserApi.md#register_register_user_auth_register_post) | **POST** /user/auth/register | Register:Register
*UserApi* | [**set_profile_picture_user_profile_current_upload_url_profile_picture_post**](docs/UserApi.md#set_profile_picture_user_profile_current_upload_url_profile_picture_post) | **POST** /user/profile/current/upload_url_profile_picture | Set Profile Picture
*UserApi* | [**set_scientist_tag_user_profile_current_set_scientist_tag_post**](docs/UserApi.md#set_scientist_tag_user_profile_current_set_scientist_tag_post) | **POST** /user/profile/current/set_scientist_tag | Set Scientist Tag
*UserApi* | [**user_profile_picture_user_profile_picture_user_id_get**](docs/UserApi.md#user_profile_picture_user_profile_picture_user_id_get) | **GET** /user/profile/picture/{user_id} | User Profile Picture
*UserApi* | [**verify_request_token_user_auth_request_verify_token_post**](docs/UserApi.md#verify_request_token_user_auth_request_verify_token_post) | **POST** /user/auth/request-verify-token | Verify:Request-Token
*UserApi* | [**verify_verify_user_auth_verify_post**](docs/UserApi.md#verify_verify_user_auth_verify_post) | **POST** /user/auth/verify | Verify:Verify


## Documentation For Models

 - [AnimalModelCreate](docs/AnimalModelCreate.md)
 - [BearerResponse](docs/BearerResponse.md)
 - [BodyVerifyRequestTokenUserAuthRequestVerifyTokenPost](docs/BodyVerifyRequestTokenUserAuthRequestVerifyTokenPost.md)
 - [BodyVerifyVerifyUserAuthVerifyPost](docs/BodyVerifyVerifyUserAuthVerifyPost.md)
 - [BrainRegionByDatasetResponse](docs/BrainRegionByDatasetResponse.md)
 - [BrainRegionCreateRead](docs/BrainRegionCreateRead.md)
 - [BrainRegionRead](docs/BrainRegionRead.md)
 - [BrainStructure](docs/BrainStructure.md)
 - [CreateDatasetCollectionMultiBrainRegion](docs/CreateDatasetCollectionMultiBrainRegion.md)
 - [CreateReadDatasetCollectionModel](docs/CreateReadDatasetCollectionModel.md)
 - [CulturalModelAnimalName](docs/CulturalModelAnimalName.md)
 - [DataLicense](docs/DataLicense.md)
 - [DatasetErrorDetail](docs/DatasetErrorDetail.md)
 - [DatasetErrorModel](docs/DatasetErrorModel.md)
 - [DatasetFilterSchema](docs/DatasetFilterSchema.md)
 - [DatasetId2SyndbTables](docs/DatasetId2SyndbTables.md)
 - [DatasetSearchResultSchema](docs/DatasetSearchResultSchema.md)
 - [DatasetTagSearchSchema](docs/DatasetTagSearchSchema.md)
 - [DatasetUploadBenchmarkResultSchema](docs/DatasetUploadBenchmarkResultSchema.md)
 - [DatasetUploadBenchmarkResultsSchema](docs/DatasetUploadBenchmarkResultsSchema.md)
 - [Detail](docs/Detail.md)
 - [ErrorModel](docs/ErrorModel.md)
 - [FileErrorDetail](docs/FileErrorDetail.md)
 - [FileErrorModel](docs/FileErrorModel.md)
 - [GeneExpression](docs/GeneExpression.md)
 - [HTTPValidationError](docs/HTTPValidationError.md)
 - [Id2LabelResponse](docs/Id2LabelResponse.md)
 - [IdResponse](docs/IdResponse.md)
 - [IdsResponse](docs/IdsResponse.md)
 - [LocationInner](docs/LocationInner.md)
 - [MicroscopyCreateRead](docs/MicroscopyCreateRead.md)
 - [ModelAnimal](docs/ModelAnimal.md)
 - [MultiBrainRegionDatasetDefinition](docs/MultiBrainRegionDatasetDefinition.md)
 - [MutationModelCreateRead](docs/MutationModelCreateRead.md)
 - [MutationModelRead](docs/MutationModelRead.md)
 - [NeuroanatomicalDirection](docs/NeuroanatomicalDirection.md)
 - [NeurodataDownloadBenchmarkResultSchema](docs/NeurodataDownloadBenchmarkResultSchema.md)
 - [NeurodataDownloadBenchmarkResultsSchema](docs/NeurodataDownloadBenchmarkResultsSchema.md)
 - [NewDatasetSchema](docs/NewDatasetSchema.md)
 - [OAuth2AuthorizeResponse](docs/OAuth2AuthorizeResponse.md)
 - [PreSignedS3DownloadSchema](docs/PreSignedS3DownloadSchema.md)
 - [PreSignedS3DownloadUrlSchema](docs/PreSignedS3DownloadUrlSchema.md)
 - [PreSignedS3UploadUrlSchema](docs/PreSignedS3UploadUrlSchema.md)
 - [PublicationCreateRead](docs/PublicationCreateRead.md)
 - [Response403UploadDatasetFilesNeurodataIoDatasetIdUploadPatch](docs/Response403UploadDatasetFilesNeurodataIoDatasetIdUploadPatch.md)
 - [S3Instance](docs/S3Instance.md)
 - [S3PreSignedDownloadRequest](docs/S3PreSignedDownloadRequest.md)
 - [SearchResultDataDownload](docs/SearchResultDataDownload.md)
 - [SingleDatasetSchemaNoBrainRegion](docs/SingleDatasetSchemaNoBrainRegion.md)
 - [SyndbErrorModel](docs/SyndbErrorModel.md)
 - [SyndbTable](docs/SyndbTable.md)
 - [UniversalMetadataResponse](docs/UniversalMetadataResponse.md)
 - [UploadedSingleDatasetSchema](docs/UploadedSingleDatasetSchema.md)
 - [UserCreate](docs/UserCreate.md)
 - [UserMetadataResponse](docs/UserMetadataResponse.md)
 - [UserProfile](docs/UserProfile.md)
 - [UserRead](docs/UserRead.md)
 - [ValidationError](docs/ValidationError.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="OAuth2PasswordBearer"></a>
### OAuth2PasswordBearer

- **Type**: OAuth
- **Flow**: password
- **Authorization URL**: 
- **Scopes**: N/A


## Author




